'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var web3_js = require('@solana/web3.js');
var bs58 = require('bs58');
var Instruction = require('./Instruction.cjs');
var PublicKey = require('./PublicKey.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var bs58__default = /*#__PURE__*/_interopDefaultLegacy(bs58);

function fromWeb3JsMessage(message) {
  return {
    version: message.version,
    header: message.header,
    accounts: message.staticAccountKeys.map(PublicKey.fromWeb3JsPublicKey),
    recentBlockhash: message.recentBlockhash,
    instructions: message.compiledInstructions.map(instruction => ({
      programIndex: instruction.programIdIndex,
      accountIndexes: instruction.accountKeyIndexes,
      data: instruction.data
    })),
    addressLookupTables: message.addressTableLookups.map(lookup => ({
      address: PublicKey.fromWeb3JsPublicKey(lookup.accountKey),
      writableIndexes: lookup.writableIndexes,
      readonlyIndexes: lookup.readonlyIndexes
    }))
  };
}
function toWeb3JsMessage(message) {
  if (message.version === 'legacy') {
    return new web3_js.Message({
      header: message.header,
      accountKeys: message.accounts.map(PublicKey.toWeb3JsPublicKey),
      recentBlockhash: message.recentBlockhash,
      instructions: message.instructions.map(instruction => ({
        programIdIndex: instruction.programIndex,
        accounts: instruction.accountIndexes,
        data: bs58__default["default"].encode(instruction.data)
      }))
    });
  }
  return new web3_js.MessageV0({
    header: message.header,
    staticAccountKeys: message.accounts.map(PublicKey.toWeb3JsPublicKey),
    recentBlockhash: message.recentBlockhash,
    compiledInstructions: message.instructions.map(instruction => ({
      programIdIndex: instruction.programIndex,
      accountKeyIndexes: instruction.accountIndexes,
      data: instruction.data
    })),
    addressTableLookups: message.addressLookupTables.map(lookup => ({
      accountKey: PublicKey.toWeb3JsPublicKey(lookup.address),
      writableIndexes: lookup.writableIndexes,
      readonlyIndexes: lookup.readonlyIndexes
    }))
  });
}
function toWeb3JsMessageFromInput(input) {
  if (input.version === 'legacy') {
    return web3_js.Message.compile({
      payerKey: PublicKey.toWeb3JsPublicKey(input.payer),
      instructions: input.instructions.map(Instruction.toWeb3JsInstruction),
      recentBlockhash: input.recentBlockhash
    });
  }
  return web3_js.MessageV0.compile({
    payerKey: PublicKey.toWeb3JsPublicKey(input.payer),
    instructions: input.instructions.map(Instruction.toWeb3JsInstruction),
    recentBlockhash: input.recentBlockhash,
    addressLookupTableAccounts: input.addressLookupTables?.map(account => new web3_js.AddressLookupTableAccount({
      key: PublicKey.toWeb3JsPublicKey(account.address),
      state: {
        ...account,
        authority: account.authority ? PublicKey.toWeb3JsPublicKey(account.authority) : undefined,
        addresses: account.addresses.map(PublicKey.toWeb3JsPublicKey)
      }
    }))
  });
}

exports.fromWeb3JsMessage = fromWeb3JsMessage;
exports.toWeb3JsMessage = toWeb3JsMessage;
exports.toWeb3JsMessageFromInput = toWeb3JsMessageFromInput;
//# sourceMappingURL=TransactionMessage.cjs.map
